@@ -23,14 +23,6 @@ decodeFail = testCase "decodeE" $
     let res = decodeE "aaaaa"
     in assertBool "fails on bad input" $ isLeft res
 
-decodeRGB16 :: FilePath -> TestTree
-decodeRGB16 fp = testCase fp $ do
-    res <- decodeE <$> BS.readFile fp
-    case res of
-        Right ImageRGBA16{} -> assertBool "decodes 16-bit" True
-        Right _             -> assertFailure "expected 16-bit color."
-        Left err            -> assertFailure (show err)
-
 decodeNoThrow :: FilePath -> TestTree
 decodeNoThrow fp = testCase fp $ do
     res <- decodeE <$> BS.readFile fp
@@ -41,5 +33,5 @@ decodeNoThrow fp = testCase fp $ do
 decEncNoThrow :: FilePath -> TestTree
 decEncNoThrow fp = testCase fp $ do
     bytes <- BS.readFile fp
-    let res = encode ((\(ImageRGBA8 img) -> img) $ decode bytes)
+    let res = encode (decode bytes)
     assertBool "Doesn't throw exception" (res `deepseq` True)
